Utility functions for the dcrypt library
This crate provides common utilities and helpers that are used by other dcrypt crates but are not part of the public API.
Modules
- data_
conversion - Text/binary conversion helpers require an allocator. data_conversion.rs